@@ -31,7 +31,7 @@ Version 0.01
 
 =cut
 
-our $VERSION = '2.36';
+our $VERSION = '2.37';
 
 =head1 SYNOPSIS
 
@@ -42,7 +42,7 @@ Indepth documentation is at https://wcmc-q.atlassian.net/wiki/display/HPCSLURM/H
 
     Main->new_with_options(infile => '/path/to/commands');
 
-This module is a wrapper around sbatch and can be used to submit arbirtary bash commands to slurm. 
+This module is a wrapper around sbatch and can be used to submit arbirtary bash commands to slurm.
 
 It has two levels of management. The first is the main sbatch command, and the second is the actual job, which runs commands in parallel, controlled by HPC::Runner::Threads or HPC::Runner::MCE.
 
@@ -129,7 +129,7 @@ has 'module' => (
     isa => 'ArrayRef',
     required => 0,
     documentation => q{List of modules to load ex. R2, samtools, etc},
-); 
+);
 
 =head2 jobname
 
@@ -216,7 +216,7 @@ has 'partition' => (
 Defaults to the nodes on the defq queue
 
 =cut
- 
+
 has 'nodelist' => (
     is => 'rw',
     isa => 'ArrayRef',
@@ -224,10 +224,10 @@ has 'nodelist' => (
     documentation => q{List of nodes to submit jobs to. Defaults to the partition with the most nodes.},
 );
 
-=head2 submit_slurm 
+=head2 submit_slurm
 
 Bool value whether or not to submit to slurm. If you are looking to debug your files, or this script you will want to set this to zero.
-Don't submit to slurm with --nosubmit_to_slurm from the command line or 
+Don't submit to slurm with --nosubmit_to_slurm from the command line or
 $self->submit_to_slurm(0); within your code
 
 =cut
@@ -261,7 +261,7 @@ has 'template_file' => (
 #!/bin/bash
 #
 #SBATCH --share
-#SBATCH --get-user-env 
+#SBATCH --get-user-env
 #SBATCH --job-name=[% JOBNAME %]
 #SBATCH --output=[% OUT %]
 [% IF PARTITION %]
@@ -272,7 +272,7 @@ has 'template_file' => (
 [% END %]
 #SBATCH --cpus-per-task=[% CPU %]
 [% IF AFTEROK %]
-#SBATCH --dependency=afterok:[% AFTEROK %] 
+#SBATCH --dependency=afterok:[% AFTEROK %]
 [% END %]
 
 [% IF MODULE %]
@@ -293,6 +293,7 @@ EOF
 =head2 serial
 Option to run all jobs serially, one after the other, no parallelism
 The default is to use 4 procs
+
 =cut
 
 has serial => (
@@ -318,7 +319,7 @@ has 'user' => (
     documentation => q{This defaults to your current user ID. This can only be changed if running as an admin user}
 );
 
-=head2 use_threads 
+=head2 use_threads
 
 Bool value to indicate whether or not to use threads. Default is uses processes
 
@@ -334,7 +335,7 @@ has 'use_threads' => (
     documentation => q{Use threads to run jobs},
 );
 
-=head2 use_processes 
+=head2 use_processes
 
 Bool value to indicate whether or not to use processes. Default is uses processes
 
@@ -348,7 +349,7 @@ has 'use_processes' => (
     documentation => q{Use processes to run jobs},
 );
 
-=head2 use_gnuparallel 
+=head2 use_gnuparallel
 
 Bool value to indicate whether or not to use processes. Default is uses processes
 
@@ -586,7 +587,7 @@ sub run {
 
 =head2 check_files()
 
-Check to make sure the outdir exists. 
+Check to make sure the outdir exists.
 If it doesn't exist the entire path will be created
 
 =cut
@@ -621,7 +622,7 @@ sub get_nodes{
         print "If you define a nodelist you must define a partition!\n";
         die;
     }
-    
+
     my @s = `sinfo -r`;
     my $href;
 
@@ -631,7 +632,7 @@ sub get_nodes{
         next if $s =~ m/^PARTITION/i;
         my @t = ($s =~ /(\S+)/g);
         $t[0] =~ s/\*//g;
-        next unless $t[1] =~ m/up/; 
+        next unless $t[1] =~ m/up/;
 
         my $nodes = $t[5];
 
@@ -760,12 +761,12 @@ sub parse_file_slurm{
                 $self->add_cmd("\n");
                 $self->add_batch("\n");
                 $self->clear_cmd;
-                $self->inc_cmd_counter; 
+                $self->inc_cmd_counter;
             }
         }
         else{
             $self->add_cmd($line);
-            
+
             if($line =~ m/\\$/){
                 $self->add_batch($line);
                 next;
@@ -784,7 +785,7 @@ sub parse_file_slurm{
             }
             else{
                 #Don't want to increase command count for wait and newnode
-                $self->inc_cmd_counter; 
+                $self->inc_cmd_counter;
             }
             $self->add_batch($line."\n") if $self->has_cmd;
             $DB::single=2;
@@ -833,11 +834,11 @@ Write out template, submission job, and infile for parallel runner
 sub process_batch{
     my $self = shift;
     my($cmdfile, $slurmfile, $slurmsubmit, $fh, $command);
-    
-    $self->cmdfile($self->outdir."/".$self->jobname."_".$self->batch_counter.".in");
-    $self->slurmfile($self->outdir."/".$self->jobname."_".$self->batch_counter.".sh"); 
 
-    $fh = IO::File->new( $self->cmdfile, q{>} ) or print "Error opening file  ".$self->cmdfile."  ".$!; 
+    $self->cmdfile($self->outdir."/".$self->jobname."_".$self->batch_counter.".in");
+    $self->slurmfile($self->outdir."/".$self->jobname."_".$self->batch_counter.".sh");
+
+    $fh = IO::File->new( $self->cmdfile, q{>} ) or print "Error opening file  ".$self->cmdfile."  ".$!;
 
     print $fh $self->batch if defined $fh && defined $self->batch;
     $fh->close;
@@ -866,13 +867,13 @@ sub process_batch{
 
     $DB::single=2;
 
-    $self->template->process($self->template_file, 
-        { JOBNAME => $self->jobname."_".$self->batch_counter, 
-            USER => $self->user, 
-            NODE => $self->node, 
-            CPU => $self->cpus_per_task, 
+    $self->template->process($self->template_file,
+        { JOBNAME => $self->jobname."_".$self->batch_counter,
+            USER => $self->user,
+            NODE => $self->node,
+            CPU => $self->cpus_per_task,
             PARTITION => $self->partition,
-            AFTEROK => $ok, 
+            AFTEROK => $ok,
             OUT => $self->logdir."/".$self->jobname."_".$self->batch_counter.".log",
             MODULE => $self->module,
             COMMAND => $command },
@@ -886,12 +887,12 @@ sub process_batch{
 
 =head2 submit_slurm()
 
-Submit jobs to slurm queue using sbatch. 
+Submit jobs to slurm queue using sbatch.
 
 This subroutine was just about 100% from the following perlmonks discussions. All that I did was add in some logging.
 
 http://www.perlmonks.org/?node_id=151886
-You can use the script at the top to test the runner. Just download it, make it executable, and put it in the infile as 
+You can use the script at the top to test the runner. Just download it, make it executable, and put it in the infile as
 
 perl command.pl 1
 perl command.pl 2
@@ -915,7 +916,7 @@ sub submit_slurm{
 
     my $sel = new IO::Select; # create a select object
     $sel->add($outfh,$errfh); # and add the fhs
-    
+
     my($stdout, $stderr, $jobid);
 
     while(my @ready = $sel->can_read) {
@@ -928,7 +929,7 @@ sub submit_slurm{
                 $self->log->fatal("Error from child: $!");
             } elsif ($len == 0){
                 # Finished reading from this FH because we read
-                # 0 bytes.  Remove this handle from $sel.  
+                # 0 bytes.  Remove this handle from $sel.
                 $sel->remove($fh);
                 next;
             } else { # we read data alright
@@ -947,7 +948,7 @@ sub submit_slurm{
 
     waitpid($cmdpid, 1);
     my $exitcode = $?;
-    
+
     ($jobid) = $stdout =~ m/Submitted batch job (\d.*)$/ if $stdout;
     if(!$jobid){
         print "No job was submitted! Please check to make sure you have loaded modules shared and slurm!\nFull error is:\t$stderr\n$stdout\nEnd Job error";
@@ -971,8 +972,6 @@ the web interface at L<http://rt.cpan.org/NoAuth/ReportBug.html?Queue=HPC-Runner
 automatically be notified of progress on your bug as I make changes.
 
 
-
-
 =head1 SUPPORT
 
 You can find documentation for this module with the perldoc command.
@@ -1002,14 +1001,16 @@ L<http://search.cpan.org/dist/HPC-Runner-Slurm/>
 
 =back
 
+=head1 Acknowledgements
 
-=head1 ACKNOWLEDGEMENTS
-
-This module was originally developed at and for Weill Cornell Medical College in Qatar. With approval from WCMC-Q, this information was generalized and put on github, for which the authors would like to express their gratitude.
+This module was originally developed at and for Weill Cornell Medical
+College in Qatar within ITS Advanced Computing Team. With approval from
+WCMC-Q, this information was generalized and put on github, for which
+the authors would like to express their gratitude.
 
 =head1 LICENSE AND COPYRIGHT
 
-Copyright 2014 Jillian Rowe.
+Copyright 2014 Weill Cornell Medical College in Qatar.
 
 This program is free software; you can redistribute it and/or modify it
 under the terms of the the Artistic License (2.0). You may obtain a
@@ -1052,4 +1053,5 @@ EVEN IF ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.
 
 __PACKAGE__->meta->make_immutable;
 #use namespace::autoclean;
-1; # End of Runner::Slurm
+
+1;
